==> kubernetes-model-admissionregistration-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/admission/v1/AdmissionResponseFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1;

import io.fabric8.kubernetes.api.model.Status;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdmissionResponseFluent<A extends io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getAllowed();
  public A withAllowed(java.lang.Boolean allowed);
  public java.lang.Boolean hasAllowed();
  public A addToAuditAnnotations(java.lang.String key,java.lang.String value);
  public A addToAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromAuditAnnotations(java.lang.String key);
  public A removeFromAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getAuditAnnotations();
  public <K,V>A withAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> auditAnnotations);
  public java.lang.Boolean hasAuditAnnotations();
  public java.lang.String getPatch();
  public A withPatch(java.lang.String patch);
  public java.lang.Boolean hasPatch();
  
  /**
   * Method is deprecated. use withPatch instead.
   */
  @java.lang.Deprecated
  public A withNewPatch(java.lang.String arg0);
  public java.lang.String getPatchType();
  public A withPatchType(java.lang.String patchType);
  public java.lang.Boolean hasPatchType();
  
  /**
   * Method is deprecated. use withPatchType instead.
   */
  @java.lang.Deprecated
  public A withNewPatchType(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.Status getStatus();
  public A withStatus(io.fabric8.kubernetes.api.model.Status status);
  public java.lang.Boolean hasStatus();
  public java.lang.String getUid();
  public A withUid(java.lang.String uid);
  public java.lang.Boolean hasUid();
  
  /**
   * Method is deprecated. use withUid instead.
   */
  @java.lang.Deprecated
  public A withNewUid(java.lang.String arg0);
  public A addToWarnings(java.lang.Integer index,java.lang.String item);
  public A setToWarnings(java.lang.Integer index,java.lang.String item);
  public A addToWarnings(java.lang.String... items);
  public A addAllToWarnings(java.util.Collection<java.lang.String> items);
  public A removeFromWarnings(java.lang.String... items);
  public A removeAllFromWarnings(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getWarnings();
  public java.lang.String getWarning(java.lang.Integer index);
  public java.lang.String getFirstWarning();
  public java.lang.String getLastWarning();
  public java.lang.String getMatchingWarning(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingWarning(java.util.function.Predicate<java.lang.String> predicate);
  public A withWarnings(java.util.List<java.lang.String> warnings);
  public A withWarnings(java.lang.String... warnings);
  public java.lang.Boolean hasWarnings();
  public A addNewWarning(java.lang.String arg0);
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/admission/v1/AdmissionResponseFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1;

import io.fabric8.kubernetes.api.model.Status;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AdmissionResponseFluent<A extends io.fabric8.kubernetes.api.model.admission.v1.AdmissionResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getAllowed();
  public A withAllowed(java.lang.Boolean allowed);
  public java.lang.Boolean hasAllowed();
  public A addToAuditAnnotations(java.lang.String key,java.lang.String value);
  public A addToAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromAuditAnnotations(java.lang.String key);
  public A removeFromAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getAuditAnnotations();
  public <K,V>A withAuditAnnotations(java.util.Map<java.lang.String,java.lang.String> auditAnnotations);
  public java.lang.Boolean hasAuditAnnotations();
  public java.lang.String getPatch();
  public A withPatch(java.lang.String patch);
  public java.lang.Boolean hasPatch();
  
  /**
   * Method is deprecated. use withPatch instead.
   */
  @java.lang.Deprecated
  public A withNewPatch(java.lang.String arg0);
  public java.lang.String getPatchType();
  public A withPatchType(java.lang.String patchType);
  public java.lang.Boolean hasPatchType();
  
  /**
   * Method is deprecated. use withPatchType instead.
   */
  @java.lang.Deprecated
  public A withNewPatchType(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.Status getStatus();
  public A withStatus(io.fabric8.kubernetes.api.model.Status status);
  public java.lang.Boolean hasStatus();
  public java.lang.String getUid();
  public A withUid(java.lang.String uid);
  public java.lang.Boolean hasUid();
  
  /**
   * Method is deprecated. use withUid instead.
   */
  @java.lang.Deprecated
  public A withNewUid(java.lang.String arg0);
  public A addToWarnings(java.lang.Integer index,java.lang.String item);
  public A setToWarnings(java.lang.Integer index,java.lang.String item);
  public A addToWarnings(java.lang.String... items);
  public A addAllToWarnings(java.util.Collection<java.lang.String> items);
  public A removeFromWarnings(java.lang.String... items);
  public A removeAllFromWarnings(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getWarnings();
  public java.lang.String getWarning(java.lang.Integer index);
  public java.lang.String getFirstWarning();
  public java.lang.String getLastWarning();
  public java.lang.String getMatchingWarning(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingWarning(java.util.function.Predicate<java.lang.String> predicate);
  public A withWarnings(java.util.List<java.lang.String> warnings);
  public A withWarnings(java.lang.String... warnings);
  public java.lang.Boolean hasWarnings();
  public A addNewWarning(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
